@@ -40,6 +40,8 @@ static const char configfile_envvar[] = "OMEGA_CONFIG_FILE";
 
 string database_dir = "/var/lib/omega/data/";
 string template_dir = "/var/lib/omega/templates/";
+string default_template = "query";
+string default_db = "default";
 string log_dir = "/var/log/omega/";
 string cdb_dir = "/var/lib/omega/cdb/";
 
@@ -59,7 +61,7 @@ try_read_config_file(const char * cfile)
     ifstream in(cfile);
     if (!in) {
 	if (file_exists(cfile))
-	    throw string("Can't open configuration file `") + cfile + "'";
+	    throw string("Can't open configuration file '") + cfile + "'";
 	return false;
     }
 
@@ -83,16 +85,20 @@ try_read_config_file(const char * cfile)
 
 	while (*q && C_isspace(*q)) ++q;
 	if (value.empty() || *q) {
-	    throw string("Bad line in configuration file `") + cfile + "'";
+	    throw string("Bad line in configuration file '") + cfile + "'";
 	}
 
-	if (*value.rbegin() != '/')
+	if (endswith(name, "_dir") && *value.rbegin() != '/')
 	    value += '/';
 
 	if (name == "database_dir") {
 	    swap(database_dir, value);
 	} else if (name == "template_dir") {
 	    swap(template_dir, value);
+	} else if (name == "default_template") {
+	    swap(default_template, value);
+	} else if (name == "default_db") {
+	    swap(default_db, value);
 	} else if (name == "log_dir") {
 	    swap(log_dir, value);
 	} else if (name == "cdb_dir") {
@@ -114,7 +120,7 @@ read_config_file()
     // First check if a location is specified in the environment variable.
     const char * cfile = getenv(configfile_envvar);
     if (cfile != NULL && cfile[0] != '\0') {
-        if (try_read_config_file(cfile)) return;
+	if (try_read_config_file(cfile)) return;
     }
 
     // Next, try reading the local config file.
