@@ -1,6 +1,6 @@
 /* diritor.cc: Iterator through entries in a directory.
  *
- * Copyright (C) 2007,2008,2010,2014 Olly Betts
+ * Copyright (C) 2007,2008,2010,2011,2012,2013,2014 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,35 +29,60 @@
 
 using namespace std;
 
+CommitAndExit::CommitAndExit(const char * msg_, const std::string & path,
+			     int errno_)
+{
+    msg = msg_;
+    msg += " \"";
+    msg += path;
+    msg += "\" (";
+    msg += strerror(errno_);
+    msg += ")";
+}
+
+CommitAndExit::CommitAndExit(const char * msg_, int errno_)
+{
+    msg = msg_;
+    msg += " (";
+    msg += strerror(errno_);
+    msg += ")";
+}
+
+CommitAndExit::CommitAndExit(const char * msg_, const char * error)
+{
+    msg = msg_;
+    msg += " (";
+    msg += error;
+    msg += ")";
+}
+
 #if defined O_NOATIME && O_NOATIME != 0
 uid_t DirectoryIterator::euid = geteuid();
 #endif
 
-#ifdef HAVE_MAGIC_H
 magic_t DirectoryIterator::magic_cookie = NULL;
-#endif
 
 void
 DirectoryIterator::call_stat()
 {
     build_path();
     int retval;
+    if (fd >= 0) {
+	retval = fstat(fd, &statbuf);
 #ifdef HAVE_LSTAT
-    if (follow_symlinks) {
-#endif
-	retval = stat(path.c_str(), &statbuf);
-#ifdef HAVE_LSTAT
-    } else {
+    } else if (!follow_symlinks) {
 	retval = lstat(path.c_str(), &statbuf);
-    }
 #endif
+    } else {
+	retval = stat(path.c_str(), &statbuf);
+    }
     if (retval == -1) {
-	string error = "Can't stat \"";
-	error += path;
-	error += "\" (";
-	error += strerror(errno);
-	error += ')';
-	throw error;
+	if (errno == ENOENT || errno == ENOTDIR)
+	    throw FileNotFound();
+	if (errno == EACCES)
+	    throw string(strerror(errno));
+	// Commit changes to files processed so far.
+	throw CommitAndExit("Can't stat", path, errno);
     }
 }
 
@@ -78,27 +103,28 @@ DirectoryIterator::start(const std::string & path_)
     path_len = path.length();
     dir = opendir(path.c_str());
     if (dir == NULL) {
-	string error = "Can't open directory \"";
-	error += path;
-	error += "\" (";
-	error += strerror(errno);
-	error += ')';
-	throw error;
+	if (errno == ENOENT || errno == ENOTDIR)
+	    throw FileNotFound();
+	if (errno == EACCES)
+	    throw string(strerror(errno));
+	// Commit changes to files processed so far.
+	throw CommitAndExit("Can't open directory", path, errno);
     }
 }
 
 void
 DirectoryIterator::next_failed() const
 {
-    string error = "Can't read next entry from directory \"";
-    error += path;
-    error += "\" (";
-    error += strerror(errno);
-    error += ')';
-    throw error;
+    // The Linux getdents() syscall (which readdir uses internally) is
+    // documented as being able to return ENOENT and ENOTDIR.  Also,
+    // EACCES has been observed here on CIFS mounts.
+    if (errno == ENOENT || errno == ENOTDIR)
+	throw FileNotFound();
+    if (errno == EACCES)
+	throw string(strerror(errno));
+    throw CommitAndExit("Can't read next entry from directory", path, errno);
 }
 
-#ifdef HAVE_MAGIC_H
 string
 DirectoryIterator::get_magic_mimetype()
 {
@@ -111,27 +137,35 @@ DirectoryIterator::get_magic_mimetype()
 	magic_cookie = magic_open(MAGIC_SYMLINK|MAGIC_MIME|MAGIC_ERROR);
 #endif
 	if (magic_cookie == NULL) {
-	    string m("Failed to initialise the file magic library: ");
-	    m += strerror(errno);
-	    throw m;
+	    // Commit changes to files processed so far.
+	    throw CommitAndExit("Failed to initialise the file magic library",
+				errno);
 	}
 	if (magic_load(magic_cookie, NULL) == -1) {
-	    string m("Failed to load the file magic database");
+	    // Commit changes to files processed so far.
 	    const char * err = magic_error(magic_cookie);
-	    if (err) {
-		m += ": ";
-		m += err;
-	    }
-	    throw m;
+	    throw CommitAndExit("Failed to load the file magic database", err);
 	}
     }
 
-    // FIXME: handle NOATIME here and share the fd with load_file().
-    build_path();
-    const char * res = magic_file(magic_cookie, path.c_str());
+    const char * res = NULL;
+    // Prior to 5.15, magic_descriptor() closed the fd passed, so avoid it.
+#if defined MAGIC_VERSION && MAGIC_VERSION - 0 >= 515
+    if (fd >= 0) {
+	if (lseek(fd, 0, SEEK_SET) == 0)
+	    res = magic_descriptor(magic_cookie, fd);
+    } else
+#endif
+    {
+	build_path();
+	res = magic_file(magic_cookie, path.c_str());
+    }
     if (!res) {
 	const char * err = magic_error(magic_cookie);
 	if (rare(err)) {
+	    int eno = magic_errno(magic_cookie);
+	    if (eno == ENOENT || eno == ENOTDIR)
+		throw FileNotFound();
 	    string m("Failed to use magic on file: ");
 	    m += err;
 	    throw m;
@@ -195,4 +229,3 @@ DirectoryIterator::get_magic_mimetype()
 
     return res;
 }
-#endif
