@@ -4,7 +4,7 @@
 /* Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2001,2005 James Aylett
  * Copyright 2001,2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Olly Betts
  * Copyright 2009 Frank J Bruzzaniti
  * Copyright 2012 Mihai Bivol
  *
@@ -84,6 +84,7 @@ static bool retry_failed;
 static bool use_ctime;
 static dup_action_type dup_action;
 static bool ignore_exclusions;
+static bool description_as_sample;
 
 static time_t last_altered_max;
 static size_t sample_size;
@@ -201,6 +202,8 @@ index_add_default_filters()
     index_command("message/rfc822",
 		  Filter(get_pkglibbindir() + "/rfc822tohtml", "text/html",
 			 false));
+    index_command("text/vcard",
+		  Filter(get_pkglibbindir() + "/vcard2text", false));
 }
 
 void
@@ -211,7 +214,7 @@ index_init(const string & dbpath, const Xapian::Stem & stemmer,
 	   size_t sample_size_, size_t title_size_, size_t max_ext_len_,
 	   bool overwrite, bool retry_failed_,
 	   bool delete_removed_documents, bool verbose_, bool use_ctime_,
-	   bool spelling, bool ignore_exclusions_)
+	   bool spelling, bool ignore_exclusions_, bool description_as_sample_)
 {
     root = root_;
     site_term = site_term_;
@@ -224,6 +227,7 @@ index_init(const string & dbpath, const Xapian::Stem & stemmer,
     verbose = verbose_;
     use_ctime = use_ctime_;
     ignore_exclusions = ignore_exclusions_;
+    description_as_sample = description_as_sample_;
 
     if (!overwrite) {
 	db = Xapian::WritableDatabase(dbpath, Xapian::DB_CREATE_OR_OPEN);
@@ -624,11 +628,13 @@ index_mimetype(const string & file, const string & urlterm, const string & url,
 		if (cmd_it->second.output_type == "text/html") {
 		    MyHtmlParser p;
 		    p.ignore_metarobots();
+		    p.description_as_sample = description_as_sample;
 		    try {
 			p.parse_html(dump, charset, false);
 		    } catch (const string & newcharset) {
 			p.reset();
 			p.ignore_metarobots();
+			p.description_as_sample = description_as_sample;
 			p.parse_html(dump, newcharset, true);
 		    } catch (ReadError) {
 			skip_cmd_failed(urlterm, context, cmd,
@@ -650,10 +656,11 @@ index_mimetype(const string & file, const string & urlterm, const string & url,
 				d.get_size(), d.get_mtime());
 		return;
 	    }
-	} else if (mimetype == "text/html") {
+	} else if (mimetype == "text/html" || mimetype == "text/x-php") {
 	    const string & text = d.file_to_string();
 	    MyHtmlParser p;
 	    if (ignore_exclusions) p.ignore_metarobots();
+	    p.description_as_sample = description_as_sample;
 	    try {
 		// Default HTML character set is latin 1, though not specifying
 		// one is deprecated these days.
@@ -661,6 +668,7 @@ index_mimetype(const string & file, const string & urlterm, const string & url,
 	    } catch (const string & newcharset) {
 		p.reset();
 		if (ignore_exclusions) p.ignore_metarobots();
+		p.description_as_sample = description_as_sample;
 		p.parse_html(text, newcharset, true);
 	    }
 	    if (!p.indexing_allowed) {
@@ -918,7 +926,8 @@ index_mimetype(const string & file, const string & urlterm, const string & url,
 	    keywords = svgparser.keywords;
 	    // FIXME: topic = svgparser.topic;
 	    author = svgparser.author;
-	} else if (mimetype == "application/x-debian-package") {
+	} else if (mimetype == "application/vnd.debian.binary-package" ||
+		   mimetype == "application/x-debian-package") {
 	    string cmd("dpkg-deb -f");
 	    append_filename_argument(cmd, file);
 	    cmd += " Description";
@@ -929,7 +938,8 @@ index_mimetype(const string & file, const string & urlterm, const string & url,
 	    if (idx != string::npos) {
 		dump.assign(desc, idx + 1, string::npos);
 	    }
-	} else if (mimetype == "application/x-redhat-package-manager") {
+	} else if (mimetype == "application/x-redhat-package-manager" ||
+		   mimetype == "application/x-rpm") {
 	    string cmd("rpm -q --qf '%{SUMMARY}\\n%{DESCRIPTION}' -p");
 	    append_filename_argument(cmd, file);
 	    const string & desc = stdout_to_string(cmd, false);
